Au–Ag alloy nanoparticle-incorporated AgBr plasmonic photocatalyst | Scientific Reports
Author: Naya, Shin-ichi
Description: A solid-phase photochemical method produces Au–Ag alloy nanoparticles (NPs) with a sharp size distribution and varying composition in AgBr crystals (Au–Ag@AgBr). These features render Au–Ag@AgBr promising as a material for the plasmonic photocatalyst further to provide a possibility of elucidating the action mechanism due to the optical tunability. This study shows that the visible-light activity of Au–Ag@AgBr for degradation of model water pollutant is very sensitive to the alloy composition with a maximum at the mole percent of Au to all Ag in AgBr (y) = 0.012 mol%. Clear positive correlation is observed between the photocatalytic activity and the quality factor defined as the ratio of the peak energy to the full width at half maximum of the localized surface plasmon resonance band. This finding indicates that Au–Ag@AgBr works as a local electromagnetic field enhancement-type plasmonic photocatalyst in which the Au–Ag NPs mainly promotes the charge separation. This conclusion was fur [cell cut: 1099 characters, first 1000 kept]
Keywords: Chemistry
Date: 2020-11-17

Skip to main content

Thank you for visiting nature.com. You are using a browser version with limited support for CSS. To obtain the best experience, we recommend you use a more up to date browser (or turn off compatibility mode in Internet Explorer). In the meantime, to ensure continued support, we are displaying the site without styles and JavaScript.

Advertisement

Au–Ag alloy nanoparticle-incorporated AgBr plasmonic photocatalyst
Download PDF

- Article
- Open Access
- Published: 17 November 2020

# Au–Ag alloy nanoparticle-incorporated AgBr plasmonic photocatalyst

- Shin-ichi Naya1 &
- Hiroaki Tada
  2

Scientific Reports volume 10, Article number: 19972 (2020) Cite this article

- 995 Accesses

- 1 Citations

- 1 Altmetric

- Metrics details

### Subjects

- Chemistry
- Nanoscience and technology

## Abstract

A solid-phase photochemical method produces Au–Ag alloy nanoparticles (NPs) with a sharp size distribution and varying composition in AgBr crystals (Au–Ag@AgBr). These features render Au–Ag@AgBr promising as a material for the plasmonic photocatalyst further to provide a possibility of elucidating the action mechanism due to the optical tunability. This study shows that the visible-light activity of Au–Ag@AgBr for degradation of model water pollutant is very sensitive to the alloy composition with a maximum at the mole percent of Au to all Ag in AgBr (y) = 0.012 mol%. Clear positive correlation is observed between the photocatalytic activity and the quality factor defined as the ratio of the peak energy to the full width at half maximum of the localized surface plasmon resonance band. This finding indicates that Au–Ag@AgBr works as a local electromagnetic field enhancement-type plasmonic photocatalyst in which the Au–Ag NPs mainly promotes the charge separation. This conclusion was further supported by the kinetic analysis of the light intensity-dependence of external quantum yield.

Download PDF

The development of technologies contributing to the solution of the energy and environmental issues and improvement in the sanitation are highly desired for the realization of sustainable and safe society. A key material is unambiguously photocatalysts among which plasmonic photocatalysts consisting of plasmonic metal nanoparticle (NP) and semiconductor have recently attracted much attention as a new type of visible-light photocatalysts1,2,3,4. The plasmonic metal NPs strongly absorb visible light due to the localized surface plasmon resonance (LSPR) originating from the collective oscillation of free electrons coupled with the electromagnetic field of the incident light. The plasmonic photocatalysts can be categorized into the hot-electron transfer (HET)-type and the local electromagnetic field-enhanced (LEFE)-type (or the plasmon-resonant energy-transfer-type)5. The former is driven by the LSPR-induced hot electron injection from plasmonic metal NP to semiconductor, and in the latter, the excitation of semiconductor is enhanced by the LSPR-induced intense electromagnetic field. So far, the HET-type plasmonic photocatalysts including Au(core)–Ag(shell) NP-loaded TiO26 have mainly been studied. On the other hand, silver-silver halides (Ag–AgX, X = Cl, Br, I) constitute a family of the plasmonic photocatalysts applicable to solar-to-fuel conversions including CO2 reduction7,8,9,10, H2 evolution reaction,11,12 and N2 fixation13 in addition to environmental remediation14 and sterilization of bacteria15. In spite of the high versatility, the action mechanism of the Ag–AgX plasmonic photocatalysts is still elusive, and its accurate understanding would underpin further improvement in the performances. The key to experimentally elucidating the action mechanism of the Ag–AgX plasmonic photocatalysts is the control of the size and composition of Ag NPs affecting the optical properties. Also, the development of the method for measuring the size of Ag NPs in the AgX matrix is necessary. Although transmission electron microscopy (TEM) is usually used for the purpose, the technique cannot be applied to Ag–AgX since it is sensitive to electron-beam irradiation.

Here we report a technique for determining the size of the plasmonic metal NPs in AgBr crystals to show that Au–Ag alloy NPs with a sharp distribution and varying composition can be formed in AgBr crystals (Au–Ag@AgBr) by a solid-phase photochemical method16. By taking advantage of the optical tunability of the Au–Ag NPs, we have revealed that the Au–Ag@AgBr plasmonic photocatalyst works as a LEFE-type plasmonic photocatalyst5, and the Au–Ag NPs mainly contribute to the charge separation enhancement by the LSPR-induced intense near-field.

## Results and discussion

### Photocatalyst characterization

Au–Ag alloy nanoparticles (NPs)-incorporated AgBr crystals (Au–Ag@AgBr) with varying composition were synthesized by the solid-phase photochemical method recently developed (Scheme 1)16. The amount of Au and Ag in Au–Ag@AgBr were determined by inductively coupled plasma (ICP) spectroscopy. The dose of Au was expressed by y (mol%) = (Au mole/all Ag mole in Au–Ag@AgBr) × 100, and controlled at 0 ≤y≤ 0.159 mol% by the HAuCl4 concentration. In the X-ray diffraction (XRD) patterns of the samples with varying y, no diffraction peak of Au and/or Ag metal is observed because of the small amount, while the formation of AgBr is clearly confirmed (Supplementaly Fig. S1). The AgBr matrix of Au–Ag@AgBr was selectively dissolved by NaCl aqueous solution with octadecyltrimethylammonium chloride, and the metal particles were observed by TEM. High resolution (HR)-TEM image and energy dispersive X-ray spectroscopy (EDS) line analysis indicate that Au–Ag alloy NP with high crystallinity is generated in the AgBr matrix (Supplementaly Fig. S2). The TEM images of the metal NPs obtained from Au–Ag@AgBr with different Au-dose levels show that uniform nearly spherical metal NPs are produced (Fig. 1, Supplementaly Fig. S3). The mean sizes of metal NPs (d) were determined to be d= 2.90 nm at y= 0, d= 2.95 nm at y= 0.012 mol%, and d= 2.84 nm at y= 0.159 mol%, indicating that the d is almost independent of y. The standard deviation (σ) is smaller than 0.75 nm, while the values for the alloy nanoparticles prepared by usual liquid-phase methods are in the range from 1.2 to 2.1 nm17,18. The uniformity of Au–Ag metal NPs in the present solid-phase photochemical method probably results from the restriction of the metal particle growth via coalescing particles in the AgBr solid matrix19. The sharp size distribution of Au–Ag NPs enables the experimental scrutiny of the action mechanism of the Au–Ag@AgBr plasmonic photocatalyst (vide infra).

Scheme 1

Photocatalyst preparation by the solid-phase photochemical method.

Full size image
Figure 1

TEM images of the metal NPs obtained by dissolving the AgBr matrix for Au–Ag@AgBr with (a) y= 0, (b) y= 0.012 mol%, and (c) y= 0.159 mol%. Each inset shows the size distribution of metal particles.

Full size image

### Photocatalytic activity

2-Naphthol was selected as a model water pollutant since it is industrially used for the production of azo-dyes, also having no absorption in the visible region. After Au–Ag@AgBr particles (20 mg) were added to 10 µM 2-naphthol aqueous solution (20 mL, pH 6.73) and stirred in the dark for 30 min, time evolution for the degradation was traced under visible-light irradiation (λ > 400 nm) at 298 K (Fig. 2a). The light intensity was adjusted so that the intensity integrated from 420 to 485 nm was 4.0 mW cm−2 using an actinometer sensitive to the wavelength range. The degradation of 2-naphthol proceeds with irradiation, while its concentration is almost invariant in the dark. The photocatalytic activity of Au–Ag@AgBr strongly depends on the alloy composition. Strikingly, the 2-naphthol disappears within only 15 min at y= 0.012 mol%. Several intermediates containing 2,2′-dihydroxy-1,1′-binaphthyl were generated during the irradiation to be finally oxidized to CO2 in 68% yield after 24 h irradiation. In this manner, the Au–Ag@AgBr photocatalyst has a strong oxidation power to completely mineralize 2-naphthol by long-time irradiation. To check the catalyst stability, the photocatalytic degradation of 2-naphthol for 15 min was repeated 5 times using Au–Ag@AgBr (y= 0.012 mol%) (Supplemental Material Fig. S4). The high degradation yield is maintained after 5-times repetition of the reaction. The photocatalytic activity is almost maintained within an experimental error. Further, ion chromatography and ICP measurements confirmed that no leaching of Ag+ and Br− ions from the catalysts to the reaction solution occurs. The initial rate of reaction (v0) in each system was calculated from the 2-naphthol concentration at the first sampling time (15 or 30 min). The plot of v0 vs. log (y/mol%) shows a volcano-shaped curve with a maximum at y= 0.012 mol% (Fig. 2b). The highest v0 value is greater than that for non-dose sample (y= 0) by a factor of ~ 3, while further increase in y rapidly decreases the photocatalytic activity.

Figure 2

(a) Time courses for the degradation of 2-naphthol under visible-light irradiation (λ> 400 nm, light intensity I420-485= 4.0 mW cm−2) by Au–Ag@AgBr with varying y and in the dark by using Au–Ag@AgBr (y= 0.012 mol%). (b) Plots of the initial reaction rate (v0) and vs. log (y/mol%).

Full size image

### Action mechanism of Au–Ag@AgBr

AgBr is a semiconductor with the indirect band gap of 2.6 eV19. In the absorption spectrum of Au–Ag@AgBr (y= 0.012 mol%) (Fig. 3a), the strong absorption band due to the interband transition rises at λ ≈ 480 nm, and the broad absorption around 600 nm results from the LSPR of Au–Ag alloy NPs. To gain information about the origin for the Au–Ag alloying effect, the action spectrum analysis was performed for the photocatalytic degradation of 2-naphthol using LEDs with different emission wavelengths. The action spectrum of the apparent quantum yield or external quantum yield (ϕex) bears good resemblance to the absorption spectrum of AgBr with no clear peak corresponding to the LSPR of the Au–Ag NPs (Fig. 3a). This result excludes the hot-electron transfer mechanism from the major route in this reaction because in the case, the action spectrum should have a peak corresponding to the LSPR absorption20.

Figure 3

(a) Action spectrum of the external quantum yield (ϕex) for the Au–Ag@AgBr (y= 0.012 mol%) photocatalyzed degradation of 2-naphthol. For comparison, the absorption spectra of Au–Ag@AgBr (y= 0.012 mol%) and AgBr are also shown. (b) Excitation band for the 2-naphthol degradation. (c) Comparison of the initial reaction rate (v0) in the Au–Ag@AgBr (y= 0.012 mol%) system under different excitation conditions. (d) Plots of reaction-enhancing ratio as a function of λex(2) with the λex(1) fixed at 420 ± 40 nm.

Full size image

The reaction was further carried out under excitation by light with λex(1) = 420 ± 40 nm or/and λex(2) = 640 ± 40 nm using two LEDs (Fig. 3b). Irradiation of Au–Ag@AgBr at λex(1) and λex(2) almost selectively excites the band gap of AgBr and the LSPR of Au–Ag NPs, respectively. The comparison of the v0 values for the excitation at λex(1), λex(2), and λex(1) +λex(2) indicates that the excitation at λex(1) causes rapid degradation of 2-naphthol, while the reaction is sluggish under the excitation at λex(2) (Fig. 3c). Simultaneous excitation (λex(1) +λex(2)) greatly enhances the reaction, i.e., the v0(λex(1) +λex(2)) is much larger than the sum of v0(λex(1)) and v0(λex(2)). A similar synergetic effect was previously observed in the Ag NP-deposited AgI system21. Further, λex(2) was changed from 470 to 850 nm with the λex(1) fixed at 420 ± 40 nm. Plots of the enhancing ratio defined as v0(λex(1) +λex(2))/v0(λex(1)) vs. λex(2) shows that the profile is good resemblance to the LSPR absorption of the Au–Ag NPs (Fig. 3d). Evidently, the Au–Ag@AgBr photocatalyst is driven by the band-gap excitation of AgBr with the activity boosted by the LSPR of incorporated Au–Ag alloy NPs, i.e., Au–Ag@AgBr works as a LEFE-type plasmonic photocatalyst16.

The quality factor (Q-factor) defined as the ratio of the peak energy (Eres) to the full width at half maximum (Γ) of the LSPR band (Eq. 1) expresses the enhancement of the oscillation amplitude of an oscillating system with respect to the driving amplitude22.

$${\text{Q-factor}} = E_{{{\text{res}}}} /\Gamma$$
(1)

For example, the intensity of surface enhanced Raman scattering is proportional to Q4 23,24,25, and thus, the Q-factor can be an experimental quantitative indicator for the LEFE-type plasmonic photocatalyst. The absorption spectra of Au–Ag alloy colloids with varying y were measured by selectively removing the AgBr matrix, and the Q-factor was calculated from Eq. (1) from each Eres and Γ. Interestingly, the plot of v0 vs. Q-factor in the Au–Ag@AgBr systems with varying y exhibits good positive correlation between them (Fig. 4a). Thus, the unique y-dependence of the photocatalytic activity (Fig. 2b) can be explained in terms of the LEFE effect of the Au–Ag alloy NPs. However, the origin for the increase in Q-factor with a slight dose of Au into Ag NP remains unclear since simulations for Aux–Ag1−x alloy NPs at 0 ≤x≤ 1 by finite-difference time-domain method indicated that the increase in x decreases the LEFE factor with the LSPR peak wavelength redshifted26,27,28,29,30.

Figure 4

(a) Plots of v0 vs. LSPR Q-factor in the Au–Ag@AgBr photocatalyzed degradation of 2-naphthol. (b) The plot of ln v0 vs ln I in the same reaction as Fig. 3a where I is the intensity of incident light.

Full size image

Based on these results, we discuss the action mechanism of Au–Ag@AgBr in the photocatalytic degradation of 2-naphthol (Scheme 2). Visible light (λ> 400 nm) excites the electrons in the valence band (vb) of AgBr to the conduction band (cb) simultaneously with the LSPR of Au–Ag alloy NPs. The excited electrons in the cb of AgBr possess a high energy of − 3.40 eV vs. vacuum19 to cause oxygen reduction reaction with a redox potential of E(O2/O2−) = − 4.16 V vs. vacuum at pH 6.7331. The remaining holes in the vb and superoxide radicals can oxidize the adsorbed 2-naphthol finally to CO2. The LSPR-induced LEFE effect of Au–Ag alloy NPs can enhance the photoexcitation of AgBr and the charge separation to boost the photocatalytic activity. A previous study on hollow AgI–Ag plasmonic photocatalyst suggests that its high visible-light activity for Rhodamine B degradation results from the increase in the rate of electron–hole pair generation in AgI by the amplified near-field of Ag NP-LSPR32. For this scheme to effectively work, significant overlap between the interband transition band of semiconductor and the LSPR of metal NPs is necessary33. However, in the Au–Ag@AgBr system, the spectral overlap between them is small, and thus, the charge separation enhancement effect would mainly contribute to the increase in the photocatalytic activity.

Scheme 2

Reaction mechanism proposed for the Au–Ag@AgBr-photocatalyst.

Full size image

In the photocatalytic degradation of 2-naphthol, the application of the steady-state approximation to the excited electrons and holes yields Eq. (2) relating ϕex and incident light intensity I under the conditions of ϕex<  <α (light absorption by photocatalyst) (see Supplemental Material Method). In this case, αI expresses the generating rate of electron–hole pairs.

$${1}/\phi_{{{\text{ex}}}} \approx \, (k_{{{\text{rec}}}} /k_{{{\text{red}}}} k_{{{\text{ox}}}} \left[ {{2} - {\text{naphthol}}_{{{\text{ad}}}} } \right]\left[ {{\text{O}}_{{{\text{2ad}}}} } \right]\alpha )^{{{1}/{2}}} I^{{{1}/{2}}}$$
(2)

where krec is the rate constant of recombination, kred is the rate constant of oxygen reduction reaction, and kox is the rate constant for 2-naphthol oxidation.

Linear relation can be expected between 1/ϕex and I1/2, and the smaller slope (or smaller ratio of krec/kredkox[2-naphtholad][O2ad]α) indicates the greater charge separation efficiency in the system. We have recently reported that CuO cluster-surface modified BiVO4 (CuO/BiVO4) semiconductor photocatalyst34 is also active for the degradation of 2-naphthol. As predicted, the plots of ϕex vs. I1/2 for the Au–Ag@AgBr, and CuO/BiVO4 systems provide straight lines with the slopes of 1.4 × 104 and 3.5 × 105 einstein−1/2 s1/2, respectively (Fig. 4b). The much smaller slope in the Au–Ag@AgBr system further supports the conclusion that the Au–Ag NPs in AgBr greatly enhance the charge separation.

## Conclusions

The solid-phase photochemical method yields Au–Ag alloy NPs with a sharp size distribution and varying composition in AgBr crystals (Au–Ag@AgBr). A slight amount of Au-dosing gives rise to a drastic increase in the photocatalytic activity for the degradation of 2-naphthol used as a model water pollutant. Clear positive correlation between the photocatalytic activity and the LSPR-quality factor of Au–Ag NPs indicates that the striking Au–Ag alloy effect is mainly induced by the charge separation enhancement due to the intense local electric field generated at the interface between Au–Ag NP and AgBr. These conclusions would also be valid for other silver halide-based systems, underpinning their further development as the plasmonic photocatalysts for the solar-to-fuel conversion and environmental purification.

## Methods

### Catalyst preparation and characterization

The catalysts were prepared by the solid-phase photochemical method recently developed14. KBr (12 mmol) and HAuCl4 was dissolved into distilled water (80 mL). To the solution, AgNO3 aqueous solution (0.1 M, 40 mL) was dropwise slowly by means of perista pump with 0.5 mL min−1. After stirring at room temperature for 1 h, the generating particles were collected by centrifugation. The sample was washed with distilled water several times, and dried in vacuo to form AgBr:Au+. The particles (0.1 g) were added to MeOH (20 mL), and re-dispersed by ultrasonication. UV-light (λ= 365 nm, the light intensity integrated from 310 to 420 nm (I310–420) = 4.0 mW cm−2) was irradiated by using LED at room temperature for 15 min. The resulting particles were washed with distilled water several times, and dried in vacuo to yield Au–Ag@AgBr. The Au amount was determined by inductively coupled plasma spectroscopy (ICPS-7000, Shimadzu). The y value was varied in the range at 0 ≤y≤ 0.159 mol% by changing the concentration of HAuCl4. Transmission electron microscopy (TEM) observation was carried out by means of JEOL JEM-2100F with an applied voltage of 200 kV. By using UV-2600 spectrometer (Shimadzu) with integrating sphere unit (Shimadzu, ISR-2600Plus), diffuse reflectance UV–Vis-NIR spectra of the samples were measured at room temperature. The reflectance (R∞) was obtained with respect to BaSO4 as a reference, and the Kubelka–Munk function [F(R∞) =  = (1 −R∞)2/2R∞] was used for the calculation of the relative absorption coefficient.

### Photocatalytic decomposition of 2-naphthol

Au–Ag@AgBr (20 mg) was added to an aqueous solution of 2-naphthol (10 µM, 20 mL) with 1% acetonitrile. Acetonitrile with a wide potential window was added for complete dissolution of 2-naphthol. The suspension was stirred in the dark for 30 min, and then, illumination was carried out by using a 300 W Xe lamp (HX-500, Wacom) with a cut off filter L-42 (λ> 400 nm, AGC TECHNO GLASS) in a double jacket type reaction cell. The cell was kept at 25 °C by circulating thermostated water through an outer jacket around the cell. The light intensity (I420–485) was adjusted to 4.0 mW cm−2 using an actinometer sensitive to the wavelength range from 420 to 485 nm. The 2-naphthol concentration was determined by high-performance liquid chromatography (Prominence, Shimadzu) [measurement conditions: λ= 223 nm; Shim-pack CLC-ODS (ϕ 4.6 mm × 150 mm) (Shimadzu); mobile phase H2O : MeOH = 3 : 7; flow rate = 1 mL min−1;]. The amount of CO2 generated was measured by gas chromatography (GC-2014, C-R8A with methanizer MTN-1 (Shimadzu)) [measurement conditions: N2 flow rate = 50 mL min−1; column = Porapak-Q 80–100 (GL science)].

## References

1. 1.

   Ueno, K. & Misawa, H. Surface plasmon-enhanced photochemical reactions. J. Photochem. Photobiol. C Photochem. Rev. 15, 31–52 (2013).

   CAS Article Google Scholar

2. 2.

   Lang, X., Chen, X. & Zhao, J. Heterogeneous visible light photocatalysis for selective organic transformations. Chem. Soc. Rev. 43, 473–486 (2014).

   CAS Article Google Scholar

3. 3.

   Panayotov, D. A. & Morris, J. R. Surface chemistry of Au/TiO2: thermally and photolytically activated reactions. Surf. Sci. Rep. 71, 77–271 (2016).

   ADS CAS Article Google Scholar

4. 4.

   Liu, L. et al. Metal nanoparticles induced photocatalysis. Nat. Sci. Rev. 4, 761–780 (2017).

   ADS CAS Article Google Scholar

5. 5.

   Tada, H. Overall water splitting and hydrogen peroxide synthesis by gold nanoparticle-based plasmonic photocatalysts. Nanoscale Adv. 1, 4238–4245 (2019).

   ADS CAS Article Google Scholar

6. 6.

   Misra, M., Singh, N. & Gupta, R. K. Enhanced visible-light-driven photocatalytic activity of Au@Ag core–shell bimetallic nanoparticles immobilized on electrospun TiO2 nanofibers for degradation of organic compounds. Catal. Sci. Technol. 7, 570–580 (2017).

   CAS Article Google Scholar

7. 7.

   An, C. et al. Synthesis of Ag@AgBr/AgCl heterostructured nanocashews with enhanced photocatalytic performance via anion exchange. J. Mater. Chem. 22, 13153–13158 (2012).

   CAS Article Google Scholar

8. 8.

   Zhang, X., Li, J., Lu, X., Tang, C. & Lu, G. Visible light induced CO2 reduction and Rh B decolorization over electrostatic-assembled AgBr/Palygorskite. J. Colloid Interface Sci. 377, 277–283 (2012).

   ADS CAS Article Google Scholar

9. 9.

   Cai, B. et al. A distinctive red Ag/AgCl photocatalyst with efficient photocatalytic oxidative and reductive activities. J. Mater. Chem. A 2, 5280–5286 (2014).

   CAS Article Google Scholar

10. 10.

    Marszewski, M., Cao, S., Yu, J. & Jaroniec, M. Semiconductor-based photocatalytic CO2 conversion. Mater. Horiz. 2, 261–278 (2015).

    CAS Article Google Scholar

11. 11.

    Kakuta, N., Goto, N., Ohkita, H. & Mizushima, T. Silver bromide as a photocatalyst for hydrogen generation from CH3OH/H2O solution. J. Phys. Chem. B 103, 5917–5919 (1999).

    CAS Article Google Scholar

12. 12.

    Li, W. et al. Hydrogen evolution by catalyzing water splitting on two-dimensional g-C3N4-Ag/AgBr heterostructure. Appl. Surf. Sci. 494, 275–284 (2019).

    ADS CAS Article Google Scholar

13. 13.

    Chen, Y. et al. Fabrication of a Z-scheme AgBr/Bi4O5Br2 nanocomposite and its high efficiency in photocatalytic N2 fixation and dye degradation. Inorg. Chem. Front. 6, 3083–3092 (2019).

    CAS Article Google Scholar

14. 14.

    Jang, J., Li, H. & Zhang, L. New insight into daylight photocatalysis of AgBr@Ag: synergistic effect between semiconductor photocatalysis and plasmonic photocatalysis. Chem. Eur. J. 18, 6360–6369 (2012).

    Article Google Scholar

15. 15.

    Elahifard, M. R., Rahimnejad, S., Haghighi, S. & Gholami, M. R. Apatite-coated Ag/AgBr/TiO2 visible-lightphotocatalyst for destruction of bacteria. J. Am. Chem. Soc. 129, 9552–9553 (2007).

    CAS Article Google Scholar

16. 16.

    Naya, S., Fujishima, M. & Tada, H. Synthesis of Au–Ag alloy nanoparticle-incorporated AgBr crystals. Catalysts 9, 745/1-745/7 (2019).

    Article Google Scholar

17. 17.

    Gonzalez, C. M., Liu, Y. & Scaiano, J. C. Photochemical strategies for the facile synthesis of gold-silver alloy and core-shell bimetallic nanoparticles. J. Phys. Chem. C 113, 11861–11867 (2009).

    CAS Article Google Scholar

18. 18.

    Zhang, J. et al. Synthesis of metal alloy nanoparticles in solution by laser irradiation of a metal powder suspension. J. Phys. Chem. B 107, 6920–6923 (2003).

    CAS Article Google Scholar

19. 19.

    Sumi, S., Watanabe, T., Fujishima, A. & Honda, K. Effect of Cl− and Br− ions and pH on the flatband potentials of silver halide sheet crystal electrodes. Bull. Chem. Soc. Jpn. 53, 2742–2747 (1980).

    CAS Article Google Scholar

20. 20.

    Gellé, A. et al. Applications of plasmon-enhanced nanocatalysis to organic transformations. Chem. Rev. 120, 986–1041 (2020).

    Article Google Scholar

21. 21.

    Nishino, Y., Tanaka, A., Hashimoto, K. & Kominami, H. Synergy effect of photoabsorption due to band-gap excitation and surface plasmon resonance on selective photocatalytic oxidation of alcohols to ketones and aldehydes over silver-deposited silver iodide. Chem. Lett. 44, 518–520 (2015).

    CAS Article Google Scholar

22. 22.

    Gordon, T. R. et al. Shape-dependent plasmonic response and directed self-assembly in a new semiconductor building block, indium-doped cadmium oxide (ICO). Nano Lett. 13, 2857–2863 (2013).

    ADS CAS Article Google Scholar

23. 23.

    Rycenga, M. et al. Controlling the synthesis and assembly of silver nanostructures for plasmonic applications. Chem. Rev. 111, 3669–3712 (2011).

    CAS Article Google Scholar

24. 24.

    Kim, H. J. et al. Plasmon-enhanced photoelectrochemical water splitting with size-controllable gold nanodot arrays. ACS Nano 8, 10756–10765 (2014).

    CAS Article Google Scholar

25. 25.

    Reshef, O. et al. Multi resonant high-Q plasmonic metasurfaces. Nano Lett. 19, 6429–6434 (2019).

    ADS CAS Article Google Scholar

26. 26.

    Link, S., Wang, Z. L. & El-sayed, M. A. Alloy formation of gold-silver nanoparticles and the dependence of the plasmon absorption on their composition. J. Phys. Chem. B 103, 3529–3533 (1999).

    CAS Article Google Scholar

27. 27.

    Kim, K., Choi, J.-Y. & Shin, K. S. Enhanced Raman scattering in gaps formed by planar Au and Au/Ag alloy nanoparticles. J. Phys. Chem. C 117, 11421–11427 (2013).

    CAS Article Google Scholar

28. 28.

    Navas, M. P. & Soni, R. K. Laser generated Ag and Ag–Au composite nanoparticles for refractive index sensor. Appl. Phys. A 116, 879–886 (2014).

    ADS CAS Article Google Scholar

29. 29.

    Albrecht, W., van der Hoeven, J. E. S., Deng, T.-S., de Jongh, P. E. & van Blaaderen, A. fully alloyed metal nanorods with highly tunable properties. Nanoscale 9, 2845–2851 (2017).

    CAS Article Google Scholar

30. 30.

    Naya, S. et al. Solid-phase photochemical growth of composition-variable Au–Ag alloy nanoparticles in AgBr crystal. J. Phys. Chem. C 121, 20763–20768 (2017).

    CAS Article Google Scholar

31. 31.

    Denki Kagaku Binran, (ed. The Electrochem. Soc. Jpn.) 93 (Maruzen, 2000).

32. 32.

    An, C., Wang, J., Liu, J., Wang, S. & Zhang, Q.-H. Plasmonic enhancement of photocatalysis over Ag incorporated AgI hollow nanostructures. RSC Adv. 4, 2409–2413 (2014).

    CAS Article Google Scholar

33. 33.

    Ingram, D. B. & Linic, S. Water splitting on composite plasmonic-metal/semiconductor photoelectrodes: evidence for selective plasmon-induced formation of charge carriers near the semiconductor surface. J. Am. Chem. Soc. 133, 5202–5205 (2011).

    CAS Article Google Scholar

34. 34.

    Kunimoto, T., Naya, S. & Tada, H. Copper oxide cluster surface modification-induced multiple electron oxygen reduction reaction on bismuth vanadate under visible-light irradiation. J. Electrochem. Soc. 167, 116523/1-116523/7 (2020).

    ADS Article Google Scholar

Download references

## Acknowledgements

The authors acknowledge Y. Hayashido and H. Fujita for experimental support. This work was supported by JST Adaptable and Seamless Technology Transfer Program through Target-driven R&D, JSPS KAKENHI Grant-in-Aid for Scientific Research (C) no. 18K05280 and 20K05674, the Futaba Foundation, and Nippon Sheet Glass Foundation for Materials Science and Engineering.

## Author information

### Affiliations

1. Environmental Research Laboratory, Kindai University, 3-4-1, Kowakae, Higashi-Osaka, Osaka, 577-8502, Japan

   Shin-ichi Naya

2. Department of Applied Chemistry, Faculty of Science and Engineering, Kindai University, 3-4-1, Kowakae, Higashi-Osaka, Osaka, 577-8502, Japan

   Hiroaki Tada

Authors

1. Shin-ichi Naya
   View author publications

   You can also search for this author in PubMed Google Scholar

2. Hiroaki Tada
   View author publications

   You can also search for this author in PubMed Google Scholar

### Contributions

S.N.: Catalyst synthesis and characterization, photocatalytic reaction, and data analysis, H.T.: Supervision the experimental work, data analysis, and paper writing.

### Corresponding author

Correspondence to Hiroaki Tada.

## Ethics declarations

### Competing interests

The authors declare no competing interests.

## Additional information

### Publisher's note

Springer Nature remains neutral with regard to jurisdictional claims in published maps and institutional affiliations.

## Supplementary information

### Supplementary Information.

## Rights and permissions

Open Access This article is licensed under a Creative Commons Attribution 4.0 International License, which permits use, sharing, adaptation, distribution and reproduction in any medium or format, as long as you give appropriate credit to the original author(s) and the source, provide a link to the Creative Commons licence, and indicate if changes were made. The images or other third party material in this article are included in the article's Creative Commons licence, unless indicated otherwise in a credit line to the material. If material is not included in the article's Creative Commons licence and your intended use is not permitted by statutory regulation or exceeds the permitted use, you will need to obtain permission directly from the copyright holder. To view a copy of this licence, visit http://creativecommons.org/licenses/by/4.0/.

Reprints and Permissions

## About this article

### Cite this article

Naya, Si., Tada, H. Au–Ag alloy nanoparticle-incorporated AgBr plasmonic photocatalyst. Sci Rep 10, 19972 (2020). https://doi.org/10.1038/s41598-020-77062-6

Download citation

- Received: 16 September 2020

- Accepted: 05 November 2020

- Published: 17 November 2020

- DOI: https://doi.org/10.1038/s41598-020-77062-6

### Share this article

Anyone you share the following link with will be able to read this content:

Sorry, a shareable link is not currently available for this article.

Provided by the Springer Nature SharedIt content-sharing initiative

## Comments

By submitting a comment you agree to abide by our Terms and Community Guidelines. If you find something abusive or that does not comply with our terms or guidelines please flag it as inappropriate.

Download PDF

# Associated Content

Collection

### Nanotechnology enabled metallurgy

Advertisement

Sign up for the Nature Briefing newsletter — what matters in science, free to your inbox daily.

Email address
I agree my information will be processed in accordance with the Nature and Springer Nature Limited Privacy Policy.
Get the most important science stories of the day, free in your inbox. Sign up for Nature Briefing